pub unsafe extern "C-unwind" fn AudioDeviceCreateIOProcID(
in_device: u32,
in_proc: Option<unsafe extern "C-unwind" fn(u32, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, *mut c_void) -> i32>,
in_client_data: *mut c_void,
out_io_proc_id: NonNull<Option<unsafe extern "C-unwind" fn(u32, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, *mut c_void) -> i32>>,
) -> i32Expand description
Creates an AudioDeviceIOProcID from an AudioDeviceIOProc and a client data pointer.
AudioDeviceIOProcIDs allow for the client to register the same function pointer with a device multiple times
Parameter inDevice: The AudioDevice to register the IOProc with.
Parameter inProc: The AudioDeviceIOProc to register.
Parameter inClientData: A pointer to client data that is passed back to the IOProc when it is
called.
Parameter outIOProcID: The newly created AudioDeviceIOProcID.
Returns: An OSStatus indicating success or failure.
Safety
in_procmust be implemented correctly.in_client_datamust be a valid pointer or null.out_io_proc_idmust be a valid pointer.