AudioDeviceStartAtTime

Function AudioDeviceStartAtTime 

pub unsafe extern "C-unwind" fn AudioDeviceStartAtTime(
    in_device: u32,
    in_proc_id: Option<unsafe extern "C-unwind" fn(u32, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, NonNull<AudioBufferList>, NonNull<AudioTimeStamp>, *mut c_void) -> i32>,
    io_requested_start_time: NonNull<AudioTimeStamp>,
    in_flags: u32,
) -> i32
Starts IO for the given AudioDeviceIOProcID and aligns the IO cycle of the AudioDevice with the given time.

Parameter inDevice: The AudioDevice to start the IOProc on.

Parameter inProcID: The AudioDeviceIOProcID to start. Note that this can be NULL, which starts the hardware regardless of whether or not there are any IOProcs registered.

Parameter ioRequestedStartTime: A pointer to an AudioTimeStamp that, on entry, is the requested time to start the IOProc. On exit, it will be the actual time the IOProc will start.

Parameter inFlags: A UInt32 containing flags that modify how this function behaves.

Returns: An OSStatus indicating success or failure. kAudioHardwareUnsupportedOperationError will be returned if the AudioDevice does not support starting at a specific time and inProc and ioRequestedStartTime are not NULL.

Safety

  • in_proc_id must be implemented correctly.
  • io_requested_start_time must be a valid pointer.