pub unsafe extern "C-unwind" fn AudioGetHostClockFrequency() -> f64
Gets the number of ticks per second in the host time base.
Returns: A Float64 containing the number of ticks per second in the host time base.