#[repr(C)]pub struct AudioHardwareIOProcStreamUsage {
pub mIOProc: NonNull<c_void>,
pub mNumberStreams: u32,
pub mStreamIsOn: [u32; 1],
}Expand description
This structure describes which streams a given AudioDeviceIOProc will use. It is used in conjunction with kAudioDevicePropertyIOProcStreamUsage. Field: mIOProc The IOProc whose stream usage is being specified. Field: mNumberStreams The number of streams being specified. Field: mStreamIsOn An array of UInt32’s whose length is specified by mNumberStreams. Each element of the array corresponds to a stream. A value of 0 means the stream is not to be enabled. Any other value means the stream is to be used.
See also Apple’s documentation
Fields
mIOProc: NonNull<c_void>mNumberStreams: u32mStreamIsOn: [u32; 1]Trait Implementations
Sourceimpl Clone for AudioHardwareIOProcStreamUsage
impl Clone for AudioHardwareIOProcStreamUsage
Sourcefn clone(&self) -> AudioHardwareIOProcStreamUsage
fn clone(&self) -> AudioHardwareIOProcStreamUsage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioHardwareIOProcStreamUsage
Sourceimpl PartialEq for AudioHardwareIOProcStreamUsage
impl PartialEq for AudioHardwareIOProcStreamUsage
Sourcefn eq(&self, other: &AudioHardwareIOProcStreamUsage) -> bool
fn eq(&self, other: &AudioHardwareIOProcStreamUsage) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AudioHardwareIOProcStreamUsage