#[repr(transparent)]pub struct AudioHardwarePowerHint(pub u32);Expand description
The values for kAudioHardwarePropertyPowerHint
The system object property, kAudioHardwarePropertyPowerHint, allows a process to to indicate how aggressive the system can be with optimizations that save power. Note that the value of this property can be set in an application’s info.plist using the key, “AudioHardwarePowerHint”. The values for this key are the strings that correspond to the values in the enum.
This is the default value and it indicates that the system will not make any power optimizations that compromise latency or quality in order to save power. The info.plist value is “None” or the “AudioHardwarePowerHint” entry can be omitted entirely.
The system will choose to save power even at the expense of latency. The info.plist value is “Favor Saving Power”
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AudioHardwarePowerHint
impl AudioHardwarePowerHint
pub const None: AudioHardwarePowerHint
pub const FavorSavingPower: AudioHardwarePowerHint