#[repr(C)]pub struct AudioObjectPropertyAddress {
pub mSelector: u32,
pub mScope: u32,
pub mElement: u32,
}Expand description
An AudioObjectPropertyAddress collects the three parts that identify a specific property together in a struct for easy transmission. Field: mSelector The AudioObjectPropertySelector for the property. Field: mScope The AudioObjectPropertyScope for the property. Field: mElement The AudioObjectPropertyElement for the property.
See also Apple’s documentation
Fields
mSelector: u32mScope: u32mElement: u32Trait Implementations
Sourceimpl Clone for AudioObjectPropertyAddress
impl Clone for AudioObjectPropertyAddress
Sourcefn clone(&self) -> AudioObjectPropertyAddress
fn clone(&self) -> AudioObjectPropertyAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for AudioObjectPropertyAddress
Sourceimpl Debug for AudioObjectPropertyAddress
impl Debug for AudioObjectPropertyAddress
Sourceimpl PartialEq for AudioObjectPropertyAddress
impl PartialEq for AudioObjectPropertyAddress
Sourcefn eq(&self, other: &AudioObjectPropertyAddress) -> bool
fn eq(&self, other: &AudioObjectPropertyAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AudioObjectPropertyAddress